@@ -20,11 +20,16 @@ import sys
 from . import gui
 
 # Generic ac magnetometer file header names
+# DO NOT CHANGE ORDER.
+# Used in
+# - from_file() classmethod of Experiment in ac.py
+# - ac_mode_func() in cli.py
+
 HEADERS_GENERIC = [
     "field",
     "temperature",
-    "sus_re",
-    "sus_im",
+    "sus_real",
+    "sus_imaginary",
     "ac_freq",
     "ac_field"
 ]
@@ -45,14 +50,14 @@ HEADERS_SUPPORTED = {
         'AC Frequency (Hz)',
         'Frequency (Hz)'
     ],
-    'sus_re': [
+    'sus_real': [
         "m' (emu)",
         "AC X'  (emu/Oe)",
         "AC X' (emu/Oe)",
         "M' (emu)",
         "AC X' (emu/Oe)"
     ],
-    'sus_im': [
+    'sus_imaginary': [
         'm" (emu)',
         'AC X" (emu/Oe)',
         'AC X\'\' (emu/Oe)',
@@ -67,7 +72,37 @@ HEADERS_SUPPORTED = {
 }
 
 
-def parse_headers(file: str) -> tuple[list[int], list[str]]:
+def locate_data_header(file: str, data_header: str = '[Data]') -> int:
+    """
+    Check whether data_header is in file.
+
+    Parameters
+    ----------
+    file : str
+        Name of magnetometer output file
+    data_header: str, default '[Data]'
+        Line which specifies the beginning of the data block in input file
+
+    Returns
+    -------
+    int
+        line number containing data header, -1 if header not located.
+    """
+
+    data_line = -1
+
+    # Open file and store line containing data header
+    with open(file, 'r') as f:
+        for it, line in enumerate(f):
+            if data_header in line:
+                data_line = it + 1
+                break
+
+    return data_line
+
+
+def parse_headers(file: str,
+                  data_line: int) -> tuple[dict[str:int], dict[str:str]]:
     """
     Extracts headers from AC magnetometer output file and returns header name
     and column position in file
@@ -76,30 +111,35 @@ def parse_headers(file: str) -> tuple[list[int], list[str]]:
     ----------
     file : str
         Name of magnetometer output file
+    data_line: int
+        Line which specifies the beginning of the data block in input file
 
     Returns
     -------
     dict
-        Keys are generic header names given in `parser.generic`
+        Keys are generic header names given in `HEADERS_GENERIC`
         Values are column index of header in file
+        If header is not found, value is -1
     dict
-        Keys are generic header names given in `parser.generic`
+        Keys are generic header names given in `HEADERS_GENERIC`
         Values are specific header names found in file
+        If header is not found, value is empty string
     """
 
     # Open file and store all headers
     with open(file, 'r') as f:
-        for line in f:
-            if '[Data]' in line:
-                ac_headers = next(f).split(',')
+        for it, line in enumerate(f):
+            if it == data_line:
+                ac_headers = line.split(',')
                 break
 
     if '\n' in ac_headers:
         ac_headers.pop(-1)
 
     # Get indices of required headers in file
-    header_indices = {}
-    header_names = {}
+    # Set default as -1 (not found)
+    header_indices = {name: -1 for name in HEADERS_GENERIC}
+    header_names = {name: "" for name in HEADERS_GENERIC}
     for hit, header in enumerate(ac_headers):
         for key, sup_heads in HEADERS_SUPPORTED.items():
             for sup_head in sup_heads:
@@ -107,7 +147,7 @@ def parse_headers(file: str) -> tuple[list[int], list[str]]:
                     header_indices[key] = hit
                     header_names[key] = header
 
-    return header_indices, header_names
+    return header_indices, header_names, HEADERS_SUPPORTED
 
 
 class ModelStore():
@@ -1639,7 +1679,7 @@ class Measurement():
 
     @classmethod
     def from_file(cls, file: str, header_indices: dict,
-                  data_header: str = '[Data]') -> list['Measurement']:
+                  data_line: int) -> list['Measurement']:
         """
         Extracts ac susceptibility from magnetometer output file and
         returns list of experiments, one for each valid measurment
@@ -1650,51 +1690,37 @@ class Measurement():
         file : str
             Name of magnetometer output file
         header_indices : dict
-            Keys are generic header names given in `parser.generic`
+            Keys are generic header names given in `HEADERS_GENERIC`
             Values are column index of header in file
-        data_header: str, default '[Data]'
-            Line which specifies the beginning of the data block
-            in input file
+        data_line: int
+            Line which specifies the beginning of the data block in input file
 
         Returns
         -------
         list
             Measurement objects, one per temperature, per field
             List has the same order as the magnetometer file
-
         """
 
-        # Open file and store all headers
-        with open(file, 'r') as f:
-            for it, line in enumerate(f):
-                if data_header in line:
-                    header_line = it + 1
-        # If data_pointer is not present, raise and error.
-        try:
-            header_line
-        except UnboundLocalError:
-            print(
-                    '\n    ***Error*** \n',
-                    '    --data_pointer "{}"'.format(data_header),
-                    'is not present in {}\n'.format(file)
-                    )
-            exit()
-
         # Columns to extract from file - n.b. these are ordered
-        cols = [header_indices[gen] for gen in HEADERS_GENERIC]
+        # cols = [header_indices[gen] for gen in HEADERS_GENERIC]
+        cols = list(header_indices.values())
 
         # Convert strings to floats, if not possible then mark as NaN
         converters = {
             it: lambda s: (float(s.strip() or np.NaN)) for it in cols
         }
 
-        converters[header_indices['sus_re']] = cls.check_pos_sus
-        converters[header_indices['sus_im']] = cls.check_pos_sus
+        # sus_real and sus_imaginary, defined in HEADERS_GENERIC
+        real_sus = list(header_indices.keys())[2]
+        imaginary_sus = list(header_indices.keys())[3]
+        converters[header_indices[real_sus]] = cls.check_pos_sus
+        converters[header_indices[imaginary_sus]] = cls.check_pos_sus
 
         # Read required columns of file
         data = np.loadtxt(
             file,
-            skiprows=header_line+1,
+            skiprows=data_line+1,
             delimiter=',',
             converters=converters,
             usecols=cols
