@@ -42,15 +42,38 @@ def ac_mode_func(args):
     user_cfg.mass = args.mass
     user_cfg.mw = args.MW
 
-    # Get file headers
-    header_indices, header_names = ac.parse_headers(user_cfg.file_name)
+    # Check data_pointer is in file
+    data_line = ac.locate_data_header(
+        user_cfg.file_name, data_header=args.data_header
+    )
 
-    # check all headers are there
-    if len(header_indices.values()) != 6:
+    # If data_pointer is not present, print error message
+    if data_line < 0:
+        message = '\n    ***Error*** \n'
+        message += '    --data_header {}\n'.format(args.data_header)
+        message += '    is not present in \n'
+        message += '    {}\n'.format(user_cfg.file_name)
+        if args.ccfit2_exe:
+            gui.error_box(message)
+        else:
+            sys.exit(message)
+
+    # Get file headers
+    header_indices, header_names, headers_supported = ac.parse_headers(
+        user_cfg.file_name, data_line
+    )
+
+    # If any headers are not present, print error message
+    if any(val == -1 for val in header_indices.values()):
         message = '\n***Error***:'
-        message += '\nHeaders in the input file are not recognised.'
-        message += '\nRefer to manual to see valid options, and contact'
-        message += ' danielreta1@gmail.com to implement new headers.'
+        for ind, name in zip(header_indices.values(), header_names.keys()):
+            if ind == -1:
+                message += '\n {} column not found.'.format(name.upper())
+                message += '\n  Options for expected header are: '
+                for i in headers_supported[name]:
+                    message += '\n   {} '.format(i)
+        message += '\nManually change the input file or contact'
+        message += ' danielreta1@gmail.com to implement new headers.\n'
         if args.ccfit2_exe:
             gui.error_box(message)
         else:
@@ -58,11 +81,12 @@ def ac_mode_func(args):
 
     # Load data from file as unordered list of individual Measurements
     ac_measurements = ac.Measurement.from_file(
-        user_cfg.file_name, header_indices, data_header=args.data_pointer
+        user_cfg.file_name, header_indices, data_line
     )
 
     # Change of units of input susceptibility to cm^3mol^(-1)
-    if header_names["sus_im"] in ['AC X" (emu/Oe)', "AC X'' (emu/Oe)"]:
+    imaginary_sus = list(header_indices.keys())[3]
+    if header_names[imaginary_sus] in ['AC X" (emu/Oe)', "AC X'' (emu/Oe)"]:
         in_susc_units = "emu/Oe"
     else:
         in_susc_units = "emu"
@@ -607,7 +631,7 @@ def read_args(arg_list=None):
         help='log normal confidence interval. Default: 1 = 68%%.'
     )
     ac_parser.add_argument(
-        '--data_pointer',
+        '--data_header',
         metavar='<str>',
         type=str,
         default='[Data]',
@@ -633,15 +657,6 @@ def read_args(arg_list=None):
         help='Print the read-in values from the file indicated.'
     )
 
-    # Hidden argument to signify that AC is being run by the executable
-    # version of ccfit2
-    if "--ccfit2_exe" in sys.argv:
-        ac_parser.add_argument(
-            '--ccfit2_exe',
-            action='store_true',
-            help=""
-        )
-
     # Waveform
     description_Waveform = """
     Extract AC susceptibilities from waveform data
@@ -702,7 +717,7 @@ def read_args(arg_list=None):
         help='Central field value used to measure waveform data. Default=0.0.'
     )
     waveform_parser.add_argument(
-        '--data_pointer',
+        '--data_header',
         metavar='<str>',
         type=str,
         default='[Data]',
@@ -874,7 +889,19 @@ def read_args(arg_list=None):
     # which is assigned to help function
     # read sub-parser
     parser.set_defaults(func=lambda args: parser.print_help())
-    args = parser.parse_args(arg_list)
+    args, unknown_args = parser.parse_known_args(arg_list)
+
+    # Hidden argument to signify that AC is being run by the executable
+    # version of ccfit2
+    if "--ccfit2_exe" in unknown_args:
+        args.ccfit2_exe = True
+    else:
+        args.ccfit2_exe = False
+
+    for unk in unknown_args:
+        if unk != "--ccfit2_exe":
+            parser.error("Unsupported argument {}".format(unk))
+
     args.func(args)
 
     return args
